# vite-plugin-fontawesome-purge

一个用于清理未使用的 FontAwesome 图标的 Vite 插件。

## 功能

- 自动扫描项目中的 FontAwesome 图标使用情况
- 提取使用的图标并复制到指定目录
- 生成图标使用清单 JSON 文件
- 支持自定义扫描路径和匹配规则

## 安装

```bash
npm install @wemt/vite-plugin-fontawesome-purge --save-dev
```

## 使用方法

在 `vite.config.js` 中配置插件：

```javascript
import { defineConfig } from 'vite'
import wemtFontawesomePurge from '@wemt/vite-plugin-fontawesome-purge'

export default defineConfig({
  plugins: [
    wemtFontawesomePurge({
      // 可选：自定义配置
      scan: {
        path: ['src'], // 要扫描的文件路径
        ext: ['.vue'], // 要扫描的文件扩展名
        match: [/['"]([^'"]*fa-[^'"]*)['"]/g], // 匹配规则
      },
      output: {
        path: 'src/assets/fontawesome/svg', // 输出目录
        name: 'fortawesome.json', // 输出文件名
      },
      icon: {
        path: [
          'node_modules/@fortawesome/fontawesome-free/svgs/regular',
          'node_modules/@fortawesome/fontawesome-free/svgs/solid',
          'node_modules/@fortawesome/fontawesome-free/svgs/brands',
        ],
        ext: ['.svg'],
        prefix: 'fa-',
      },
    })
  ]
})
```

## 配置选项

### scan

- `path`: 要扫描的文件路径数组
- `ext`: 要扫描的文件扩展名数组
- `match`: 匹配规则数组（正则表达式）

### output

- `path`: 输出目录路径
- `name`: 输出 JSON 文件名

### icon

- `path`: 图标源文件路径数组
- `ext`: 图标文件扩展名数组
- `prefix`: 图标类名前缀

## 输出

插件会在构建过程中：

1. 扫描指定目录中的文件
2. 提取使用的 FontAwesome 图标
3. 将使用的图标复制到输出目录
4. 生成 `fortawesome.json` 文件，记录图标使用情况

## 注意事项

- 确保项目中已安装 `@fortawesome/fontawesome-free` 包
- 插件会在 Vite 构建开始时执行
- 建议将输出目录添加到版本控制中 